==> haskell-quic-0.1.6-21-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-quic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 quic
version:              0.1.6
visibility:           public
id:                   quic-0.1.6-BQAbsmAfLbdAkAfQdAQ3EH
key:                  quic-0.1.6-BQAbsmAfLbdAkAfQdAQ3EH
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             QUIC
description:
    Library for QUIC: A UDP-Based Multiplexed and Secure Transport

category:             Web
abi:                  a51c93265f86d1238710b9b28dc301e2
exposed:              True
exposed-modules:
    Network.QUIC Network.QUIC.Client Network.QUIC.Internal
    Network.QUIC.Server

hidden-modules:
    Network.QUIC.Client.Reader Network.QUIC.Client.Run
    Network.QUIC.Closer Network.QUIC.Common Network.QUIC.Config
    Network.QUIC.Connection Network.QUIC.Connection.Crypto
    Network.QUIC.Connection.Migration Network.QUIC.Connection.Misc
    Network.QUIC.Connection.PacketNumber Network.QUIC.Connection.Queue
    Network.QUIC.Connection.Role Network.QUIC.Connection.State
    Network.QUIC.Connection.Stream Network.QUIC.Connection.StreamTable
    Network.QUIC.Connection.Timeout Network.QUIC.Connection.Types
    Network.QUIC.Connector Network.QUIC.Crypto
    Network.QUIC.Crypto.Fusion Network.QUIC.Crypto.Keys
    Network.QUIC.Crypto.Nite Network.QUIC.Crypto.Types
    Network.QUIC.Crypto.Utils Network.QUIC.Event Network.QUIC.Exception
    Network.QUIC.Handshake Network.QUIC.IO Network.QUIC.Imports
    Network.QUIC.Info Network.QUIC.Logger Network.QUIC.Packet
    Network.QUIC.Packet.Decode Network.QUIC.Packet.Decrypt
    Network.QUIC.Packet.Encode Network.QUIC.Packet.Frame
    Network.QUIC.Packet.Header Network.QUIC.Packet.Number
    Network.QUIC.Packet.Token Network.QUIC.Parameters
    Network.QUIC.QLogger Network.QUIC.Qlog Network.QUIC.Receiver
    Network.QUIC.Recovery Network.QUIC.Recovery.Constants
    Network.QUIC.Recovery.Detect Network.QUIC.Recovery.Interface
    Network.QUIC.Recovery.LossRecovery Network.QUIC.Recovery.Metrics
    Network.QUIC.Recovery.Misc Network.QUIC.Recovery.PeerPacketNumbers
    Network.QUIC.Recovery.Persistent Network.QUIC.Recovery.Release
    Network.QUIC.Recovery.Timer Network.QUIC.Recovery.Types
    Network.QUIC.Recovery.Utils Network.QUIC.Sender
    Network.QUIC.Server.Reader Network.QUIC.Server.Run
    Network.QUIC.Stream Network.QUIC.Stream.Frag
    Network.QUIC.Stream.Misc Network.QUIC.Stream.Queue
    Network.QUIC.Stream.Reass Network.QUIC.Stream.Skew
    Network.QUIC.Stream.Table Network.QUIC.Stream.Types
    Network.QUIC.TLS Network.QUIC.Types Network.QUIC.Types.Ack
    Network.QUIC.Types.CID Network.QUIC.Types.Constants
    Network.QUIC.Types.Error Network.QUIC.Types.Exception
    Network.QUIC.Types.Frame Network.QUIC.Types.Integer
    Network.QUIC.Types.Packet Network.QUIC.Types.Queue
    Network.QUIC.Types.Resumption Network.QUIC.Types.Time
    Network.QUIC.Utils Network.QUIC.Windows

import-dirs:          /usr/lib/ghc-9.2.8/site-local/quic-0.1.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/quic-0.1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quic
hs-libraries:         HSquic-0.1.6-BQAbsmAfLbdAkAfQdAQ3EH
depends:
    array-0.5.4.0 base-4.16.4.0
    base16-bytestring-1.0.2.0-1EKQKfIbtqrKykCu8OdSyV
    bytestring-0.11.4.0 containers-0.6.5.1
    crypto-token-0.0.2-BmJMdyZ8Jn89fzeTupSCN0
    crypton-0.34-67uX59Sjjsw2dJbbUWUzWH
    crypton-x509-1.7.6-AT1aSHFzIIlFru8iIljDNg
    crypton-x509-system-1.6.7-93nEwprdNTvGhzbOmYM4iQ
    data-default-class-0.1.2.0-Kt3ErptCt5hHHi8l61h1Gp
    fast-logger-3.1.2-AQtkpPEy7zzKpf61wl8oWJ filepath-1.4.2.2
    iproute-1.7.12-5Hl7VCLvmHF2LaknTOyjlO
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1
    network-3.1.4.0-BwapeZNENJRGd3a4t7iBSJ
    network-byte-order-0.1.7-8Wb9MBmdsnYAp65wZlMSzk
    network-udp-0.0.0-AmzBt8O2FBp5iq39K9A4hs
    psqueues-0.2.8.0-3qqZkNXtUDt2qS4hnfH6YF
    random-1.2.1.2-BXSdRxlC6g4I8lxfKC5NFh stm-2.5.0.2
    tls-1.8.0-7h7yCI2XUOLCqAd7IRMHCz
    unix-time-0.4.13-9imUIa4eWoWCSYI5hwvBPM
    unliftio-0.2.25.0-LM0KsdTS0NHVSVsirPxfP
    unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn

haddock-interfaces:   /usr/share/doc/haskell-quic/html/quic.haddock
haddock-html:         /usr/share/doc/haskell-quic/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quic-0.1.9-13.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-quic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quic
version:              0.1.9
visibility:           public
id:                   quic-0.1.9-FrfEXXruc1v7ZEgf44vgrf
key:                  quic-0.1.9-FrfEXXruc1v7ZEgf44vgrf
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             QUIC
description:
    Library for QUIC: A UDP-Based Multiplexed and Secure Transport

category:             Web
abi:                  4b7059eddd89fe2146f92226550e8ed7
exposed:              True
exposed-modules:
    Network.QUIC Network.QUIC.Client Network.QUIC.Internal
    Network.QUIC.Server

hidden-modules:
    Network.QUIC.Client.Reader Network.QUIC.Client.Run
    Network.QUIC.Closer Network.QUIC.Common Network.QUIC.Config
    Network.QUIC.Connection Network.QUIC.Connection.Crypto
    Network.QUIC.Connection.Migration Network.QUIC.Connection.Misc
    Network.QUIC.Connection.PacketNumber Network.QUIC.Connection.Queue
    Network.QUIC.Connection.Role Network.QUIC.Connection.State
    Network.QUIC.Connection.Stream Network.QUIC.Connection.StreamTable
    Network.QUIC.Connection.Timeout Network.QUIC.Connection.Types
    Network.QUIC.Connector Network.QUIC.Crypto
    Network.QUIC.Crypto.Fusion Network.QUIC.Crypto.Keys
    Network.QUIC.Crypto.Nite Network.QUIC.Crypto.Types
    Network.QUIC.Crypto.Utils Network.QUIC.Event Network.QUIC.Exception
    Network.QUIC.Handshake Network.QUIC.IO Network.QUIC.Imports
    Network.QUIC.Info Network.QUIC.Logger Network.QUIC.Packet
    Network.QUIC.Packet.Decode Network.QUIC.Packet.Decrypt
    Network.QUIC.Packet.Encode Network.QUIC.Packet.Frame
    Network.QUIC.Packet.Header Network.QUIC.Packet.Number
    Network.QUIC.Packet.Token Network.QUIC.Parameters
    Network.QUIC.QLogger Network.QUIC.Qlog Network.QUIC.Receiver
    Network.QUIC.Recovery Network.QUIC.Recovery.Constants
    Network.QUIC.Recovery.Detect Network.QUIC.Recovery.Interface
    Network.QUIC.Recovery.LossRecovery Network.QUIC.Recovery.Metrics
    Network.QUIC.Recovery.Misc Network.QUIC.Recovery.PeerPacketNumbers
    Network.QUIC.Recovery.Persistent Network.QUIC.Recovery.Release
    Network.QUIC.Recovery.Timer Network.QUIC.Recovery.Types
    Network.QUIC.Recovery.Utils Network.QUIC.Sender
    Network.QUIC.Server.Reader Network.QUIC.Server.Run
    Network.QUIC.Stream Network.QUIC.Stream.Frag
    Network.QUIC.Stream.Misc Network.QUIC.Stream.Queue
    Network.QUIC.Stream.Reass Network.QUIC.Stream.Skew
    Network.QUIC.Stream.Table Network.QUIC.Stream.Types
    Network.QUIC.TLS Network.QUIC.Types Network.QUIC.Types.Ack
    Network.QUIC.Types.CID Network.QUIC.Types.Constants
    Network.QUIC.Types.Error Network.QUIC.Types.Exception
    Network.QUIC.Types.Frame Network.QUIC.Types.Integer
    Network.QUIC.Types.Packet Network.QUIC.Types.Queue
    Network.QUIC.Types.Resumption Network.QUIC.Types.Time
    Network.QUIC.Utils Network.QUIC.Windows

import-dirs:          /usr/lib/ghc-9.4.8/site-local/quic-0.1.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/quic-0.1.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/quic-0.1.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quic
hs-libraries:         HSquic-0.1.9-FrfEXXruc1v7ZEgf44vgrf
depends:
    array-0.5.4.0 base-4.17.2.1
    base16-bytestring-1.0.2.0-QNB00R14ilFJ2bl5pXkq5 bytestring-0.11.5.3
    containers-0.6.7 crypto-token-0.0.2-2WWQZRldxoEAycOsDxZHo1
    crypton-1.0.0-IOrX7iT0S6MJjAyhaWcbyg
    crypton-x509-1.7.6-5ENF2SSVfGHBSTcoVpD3oB
    crypton-x509-system-1.6.7-JWmDwILCta5D2Z6dV1mqBY
    data-default-class-0.1.2.0-J3yYo85AtrC9KKZSpt62Yc
    fast-logger-3.2.1-Cqq5HavO4774wMQnm19ccN filepath-1.4.2.2
    iproute-1.7.15-IZY1Nt3T6XIGF8WcjQqHbt
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    network-3.1.4.0-AQGzws0tmah75qbsifMDHb
    network-byte-order-0.1.7-D2CHdiOOdOK1rEVBtge3lM
    network-control-0.0.2-3GVVefCkcBU5AH6LOHmelz
    network-udp-0.0.0-6UJgmmsd6T21NWthuEovsO
    random-1.2.1.2-5Y3bNr2vhgE1UbXPPVLWyj stm-2.5.1.0
    tls-1.9.0-JY0bcNSsGwWY5dBxVg2a7
    unix-time-0.4.16-L41X6Qm5E9z1E3Nxq4OtJ9
    unliftio-0.2.25.1-F7Dw6tTXv5C3zxHQgA2LvN
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:   /usr/share/doc/haskell-quic/html/quic.haddock
haddock-html:         /usr/share/doc/haskell-quic/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
